/*
 * Copyright (c) 2017 Nuvoton Tecnology Corp. All rights reserved.
 *
 * Header for Serial-To-Ethernet configuration.
 *
 */

#ifndef _STE_CONFIG_H
#define _STE_CONFIG_H

/* Maximum UART ports supported */
#define MAX_UART_PORTS      1

/* Default UART baud */
#define DEFAULT_UART_BAUD   115200

#define UART_RX_BUFFER_SIZE        512
#define UART_TX_BUFFER_SIZE        512

/* Network base port number to listen.
   So the base port maps to the 1st UART port,
   the (base port + 1) maps to the 2nd UART port, etc. */
#define NET_PORT_BASE   10001

/* Path and Filename of configuration files */
#define SER_CONFIG_FILE    "/fs/STE_SER.TXT"    // for serial ports
#define NET_CONFIG_FILE "/fs/STE_NET.TXT"    // for network

/* Maximum size of server address */
//#define MAX_SERVER_ADDRESS_SIZE        63

/* Maximum size of IP address */
//#define MAX_IPV4_ADDRESS_SIZE        15

/* Functions and global variables declaration. */

typedef enum {
    NET_SERVER_MODE = 0,
    NET_CLIENT_MODE
} E_NetMode;

typedef enum {
    IP_STATIC_MODE = 0,
    IP_DHCP_MODE
} E_IPMode;

//typedef struct {
//    E_IPMode        mode;
//    char             ip[MAX_IPV4_ADDRESS_SIZE+1];
//    char             mask[MAX_IPV4_ADDRESS_SIZE+1];
//    char             gateway[MAX_IPV4_ADDRESS_SIZE+1];
//} S_NET_CONFIG;

typedef struct {
    E_NetMode        mode;            // Network server or client mode
    uint16_t         port;            // SERVER mode only, listen Network port 
    UART_T            *pserial;        // UART number
    uint32_t        baud;            // UART baud
    uint32_t         data;            // UART data bits
    uint32_t        stop;            // UART stop bits
    uint32_t         parity;         // UART parity bit
    ip_addr_t        server_addr;    // CLIENT mode only, target Server address
    uint16_t        server_port;    // CLIENT mode only, target Server port
} S_PORT_CONFIG;

//extern unsigned char SD_Card_Mounted;
//extern S_NET_CONFIG net_config;
extern S_PORT_CONFIG port_config[MAX_UART_PORTS];

//void start_httpd(void);

#endif
